.. testsetup:: *

   from pwnlib.filepointer import *

:mod:`pwnlib.filepointer` --- `FILE*` structure exploitation
============================================================

.. automodule:: pwnlib.filepointer
   :members:
